@@ -24,13 +24,18 @@ SEXP R_parse(SEXP x, SEXP bigint_as_char) {
       json = json + 3;
     }
 
+    /* ignore rfc7464 record separator */
+    if(json[0] == '\x1E'){
+      json = json + 1;
+    }
+
     /* parse json */
     char errbuf[1024];
     yajl_val node = yajl_tree_parse(json, errbuf, sizeof(errbuf));
 
     /* parser error */
     if (!node) {
-      Rf_errorcall(R_NilValue, errbuf);
+      Rf_errorcall(R_NilValue, "%s", errbuf);
     }
     SEXP out = ParseValue(node, bigint);
     yajl_tree_free(node);
